@@ -240,14 +240,18 @@ public class CkanToZendoPublisherWidget {
 					}
 					
 					JSONValue theMessage = theErrorJSON.get("message");
-					return "Error reported from Zenodo: " + theMessage.toString();
-	
-//					//GWT.log("array: "+array.toString());
-//					JSONObject theErrorValue = (JSONObject) array.get(0);
-//					//GWT.log("theErrorValue: "+theErrorValue.toString());
-//					JSONValue theMessage = theErrorValue.get("message");
-//					//GWT.log("message: "+message.toString());
-//					return "Error reported from Zenodo: " + theMessage.toString();
+					String theErrors = null;
+					try {
+						JSONValue theError = theErrorJSON.get("errors");
+						theErrors = theError.toString();
+					}catch (Exception e) {
+						//silent
+					}
+					String toReport =  "Message reported from Zenodo: " + theMessage.toString();
+					if(theErrors!=null)
+						toReport+= " Errors: "+theErrors;
+					
+					return toReport;
 				}
 			}catch (Exception e) {
 				return message;
