@@ -254,15 +254,20 @@ public class BasicInformationView extends Composite implements FormValidator {
 	private void fillForm() {
 
 		field_title.setValue(zenodoItem.getTitle());
-		InfoTextAndLabels.addFieldDescriptionInfo("title", cl_title);
+		InfoTextAndLabels.addTooltipForFieldKey("title", cl_title);
 		field_description.setValue(zenodoItem.getMetadata().getDescription());
-		InfoTextAndLabels.addFieldDescriptionInfo("description", cl_description);
-		field_doi.setValue(zenodoItem.getDoi().toString());
+		InfoTextAndLabels.addTooltipForFieldKey("description", cl_description);
+		field_doi.setValue(zenodoItem.getDoi());
 
 		ZenodoMetadata zMeta = zenodoItem.getMetadata();
 		if (zMeta != null) {
+			
 			String title = zenodoItem.getTitle() != null ? zenodoItem.getTitle() : zMeta.getTitle();
 			field_title.setValue(title); // Re.fill title to be sure
+			
+			if(zMeta.getPublication_date()!=null) {
+				field_publication_date.setValue(zenodoItem.getMetadata().getPublication_date());
+			}
 
 			// Upload type
 			if (zMeta.getUpload_type() != null) {
@@ -270,8 +275,8 @@ public class BasicInformationView extends Composite implements FormValidator {
 				FieldUtil.selectValueToListBox(field_upload_type, zMeta.getUpload_type().getSelectedValues());
 			} else
 				field_upload_type.setEnabled(false);
-
-			InfoTextAndLabels.addFieldDescriptionInfo("upload_type", cl_upload_type);
+			
+			InfoTextAndLabels.addTooltipForFieldKey("upload_type", cl_upload_type);
 
 			// Publication Type
 			if (zMeta.getPublication_type() != null) {
@@ -284,7 +289,7 @@ public class BasicInformationView extends Composite implements FormValidator {
 			} else
 				cg_publication_type.setVisible(false);
 			
-			InfoTextAndLabels.addFieldDescriptionInfo("publication_type", cl_publication_type);
+			InfoTextAndLabels.addTooltipForFieldKey("publication_type", cl_publication_type);
 			
 			if(zMeta.getImage_type() != null) {
 				FieldUtil.addValuesToListBox(field_image_type, zMeta.getImage_type().getSelectableValues());
@@ -304,7 +309,7 @@ public class BasicInformationView extends Composite implements FormValidator {
 			} else
 				field_access_right.setEnabled(false);
 
-			InfoTextAndLabels.addFieldDescriptionInfo("access_right", cl_access_right);
+			InfoTextAndLabels.addTooltipForFieldKey("access_right", cl_access_right);
 			
 			if(zMeta.getEmbargo_date()!=null) {
 				embargoDate.setValue(zMeta.getEmbargo_date());
@@ -312,14 +317,14 @@ public class BasicInformationView extends Composite implements FormValidator {
 			}else
 				cg_embargo_date.setVisible(false);
 			
-			InfoTextAndLabels.addFieldDescriptionInfo("embargo_date", cl_embargo_date);
+			InfoTextAndLabels.addTooltipForFieldKey("embargo_date", cl_embargo_date);
 			
 			if(zMeta.getAccess_conditions()!=null) {
 				field_access_conditions.setValue(zMeta.getAccess_conditions());
 			}else
 				cg_access_conditions.setVisible(false);
 			
-			InfoTextAndLabels.addFieldDescriptionInfo("access_conditions", cl_access_conditions);
+			InfoTextAndLabels.addTooltipForFieldKey("access_conditions", cl_access_conditions);
 
 			// License
 			if (zMeta.getLicenses() != null) {
@@ -339,7 +344,7 @@ public class BasicInformationView extends Composite implements FormValidator {
 			}else
 				field_license.setEnabled(false); 
 
-			InfoTextAndLabels.addFieldDescriptionInfo("license", cl_license);
+			InfoTextAndLabels.addTooltipForFieldKey("license", cl_license);
 
 			// Keywords
 			if (zMeta.getKeywords() != null && zMeta.getKeywords().size() > 0) {
@@ -410,8 +415,9 @@ public class BasicInformationView extends Composite implements FormValidator {
 			boolean isValid = FieldUtil.isValidValue(value);
 			if (!isValid) {
 				FieldUtil.setControlGroup(cgDOI, ControlGroupType.ERROR);
-				error_alert.setVisible(true);
-				error_alert.setText("This field DOI is required");
+				showErrorAlert(true, "The field DOI is required");
+//				error_alert.setVisible(true);
+//				error_alert.setText("This field DOI is required");
 				return "This field is required";
 			}
 		}
@@ -424,8 +430,9 @@ public class BasicInformationView extends Composite implements FormValidator {
 			GWT.log("isValid: " + isValid);
 			if (!isValid) {
 				FieldUtil.setControlGroup(cgTitle, ControlGroupType.ERROR);
-				error_alert.setVisible(true);
-				error_alert.setText("The field Title is required");
+				showErrorAlert(true, "The field Title is required");
+//				error_alert.setVisible(true);
+//				error_alert.setText("The field Title is required");
 				return "This field is required";
 			}
 		}
@@ -434,8 +441,9 @@ public class BasicInformationView extends Composite implements FormValidator {
 			boolean isValid = embargoDate.getValue()!=null;
 			if(!isValid) {
 				FieldUtil.setControlGroup(cg_embargo_date, ControlGroupType.ERROR);
-				error_alert.setVisible(true);
-				error_alert.setText("The field Embargo Date is required");
+				showErrorAlert(true, "The field Embargo Date is required");
+//				error_alert.setVisible(true);
+//				error_alert.setText("The field Embargo Date is required");
 				return "This field is required";
 			}
 		}
@@ -444,8 +452,9 @@ public class BasicInformationView extends Composite implements FormValidator {
 			boolean isValid = field_access_conditions.getValue()!= null && !field_access_conditions.getValue().isEmpty();
 			if(!isValid) {
 				FieldUtil.setControlGroup(cg_access_conditions, ControlGroupType.ERROR);
-				error_alert.setVisible(true);
-				error_alert.setText("The field Access Condition is required");
+				showErrorAlert(true, "The field Access Condition is required");
+//				error_alert.setVisible(true);
+//				error_alert.setText("The field Access Condition is required");
 				return "This field is required";
 			}
 		}
@@ -454,8 +463,9 @@ public class BasicInformationView extends Composite implements FormValidator {
 		for (CreatorsFormView cfv : listOfCreatorsView) {
 			String error = cfv.validateFormFields();
 			if (error != null) {
-				error_alert.setVisible(true);
-				error_alert.setText(error);
+//				error_alert.setVisible(true);
+//				error_alert.setText(error);
+				showErrorAlert(true, error);
 				return error;
 			}
 		}
@@ -464,14 +474,26 @@ public class BasicInformationView extends Composite implements FormValidator {
 		for (CreatorsFormView cfv : listOfContributorsView) {
 			String error = cfv.validateFormFields();
 			if (error != null) {
-				error_alert.setVisible(true);
-				error_alert.setText(error);
+				showErrorAlert(true, error);
+//				error_alert.setVisible(true);
+//				error_alert.setText(error);
 				return error;
 			}
 		}
 
 		return null;
 	}
+	
+	private void showErrorAlert(boolean visible, String message) {
+		error_alert.setText(message);
+		error_alert.setVisible(visible);
+		try {
+			error_alert.getElement().focus();
+		} catch (Exception e) {
+			// TODO: handle exception
+		}
+		
+	}
 
 	/*
 	 * (non-Javadoc)
